@@ -23,17 +23,17 @@ COMPRESSIONS = []
 
 def get_filetypes(session=None):
     global FILETYPES
-    if FILETYPES:
-        return FILETYPES
-    session = DBUtils.check_session(session)
-    return [ft.pk for ft in session.query(Filetype.pk)]
+    if not FILETYPES:
+        session = DBUtils.check_session(session)
+        FILETYPES = [ft.pk for ft in session.query(Filetype.pk)]
+    return FILETYPES
 
 def get_compressions(session=None):
     global COMPRESSIONS
-    if COMPRESSIONS:
-        return COMPRESSIONS
-    session = DBUtils.check_session(session)
-    return [comp.pk for comp in session.query(Compression.pk)]
+    if not COMPRESSIONS:
+        session = DBUtils.check_session(session)
+        COMPRESSIONS = [comp.pk for comp in session.query(Compression.pk)]
+    return COMPRESSIONS
 
 
 def guess_filetype(filename):
@@ -54,11 +54,9 @@ def guess_filetype(filename):
         ext  = matches.group(2).lower()
 
     post10k = re.search(r'^\d{5}(-|$)', base)
-    print(post10k)
     matches = re.search(r"-(.*)$", base)
     if matches:
         base_after_hyphen = matches.group(1)
-    print(base, base_after_hyphen, ext)
 
     # guess filetype from file extension
     ext = EXTENSION_ALIASES.get(ext, ext)
@@ -146,16 +144,17 @@ def store_file_in_database(id_, filename, type_, encoding=None, session=None):
     if type_ == 'txt' and encoding is None:
         type_ = 'txt.utf-8'
         encoding = 'utf-8'
+        check_type = False
     else:
         guess_type, guess_enc = guess_filetype(filename)
-        type_ = type_ if type_ else guess_type
+        type_, check_type = type_, True if type_ else guess_type, False
         encoding = encoding if encoding else guess_enc
 
     try:
         statinfo = os.stat(filename)
 
-        # check good filetype
-        if not session.query(Filetype).filter(Filetype.pk == type_).count():
+        # check good filetype if not from guesser
+        if check_type and not session.query(Filetype).filter(Filetype.pk == type_).count():
             warning("%s is not a valid filetype, didn't store %s", type_, filename)
             return
 
